package com.qmth.distributed.print.business.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.distributed.print.business.bean.params.obe.cultureProgram.ObeCultureProgramCourseParam;
import com.qmth.distributed.print.business.bean.result.obe.cultureProgram.CultureProgramCourseSelectResult;
import com.qmth.distributed.print.business.entity.ObeCultureProgramCourse;
import com.qmth.distributed.print.business.mapper.ObeCultureProgramCourseMapper;
import com.qmth.distributed.print.business.service.ObeCultureProgramCourseService;
import com.qmth.teachcloud.common.entity.SysUser;
import com.qmth.teachcloud.common.enums.ExceptionResultEnum;
import com.qmth.teachcloud.common.service.SysOrgService;
import com.qmth.teachcloud.common.util.ServletUtil;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Set;
import java.util.concurrent.atomic.AtomicInteger;

/**
 * <p>
 * 培养方案课程体系 服务实现类
 * </p>
 *
 * @author xf
 * @since 2024-06-05
 */
@Service
public class ObeCultureProgramCourseServiceImpl extends ServiceImpl<ObeCultureProgramCourseMapper, ObeCultureProgramCourse> implements ObeCultureProgramCourseService {

    @Resource
    private SysOrgService sysOrgService;

    @Override
    public List<CultureProgramCourseSelectResult> queryList(Long cultureProgramId, Long orgId) {
        if (orgId == null) {
            throw ExceptionResultEnum.ERROR.exception("请选择学院");
        }
        Set<Long> orgIdSet = sysOrgService.findDeepOrgIdListByOrgIdList(Arrays.asList(orgId));

        return this.baseMapper.queryList(cultureProgramId, orgIdSet);
    }

    @Override
    public List<ObeCultureProgramCourse> listCourse(Long cultureProgramId) {
        QueryWrapper<ObeCultureProgramCourse> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(ObeCultureProgramCourse::getCultureProgramId, cultureProgramId)
                .orderByAsc(ObeCultureProgramCourse::getSortNum);
        return this.list(queryWrapper);
    }

    @Override
    public boolean saveCourse(ObeCultureProgramCourseParam obeCultureProgramCourseParam) {
        SysUser sysUser = (SysUser) ServletUtil.getRequestUser();
        List<ObeCultureProgramCourse> courseList = new ArrayList<>();
        AtomicInteger i = new AtomicInteger(1);
        int maxSortNum = this.getMaxSortNum(obeCultureProgramCourseParam.getCultureProgramId());
        obeCultureProgramCourseParam.getCourses().forEach(t -> {
            ObeCultureProgramCourse obeCultureProgramCourse = new ObeCultureProgramCourse();
            obeCultureProgramCourse.setCultureProgramId(obeCultureProgramCourseParam.getCultureProgramId());
            obeCultureProgramCourse.setCourseId(t.getCourseId());
            obeCultureProgramCourse.setSortNum(maxSortNum + i.getAndIncrement());
            obeCultureProgramCourse.insertInfo(sysUser.getId());
            courseList.add(obeCultureProgramCourse);
        });

//        List<TPRequirement> tpRequirementList = tpRequirementService.listRequirement(tpCourseParam.getProfessionalId());
//        if (CollectionUtils.isNotEmpty(tpRequirementList)) {
//            // 增加矩阵数据
//            for (TPCourse tpCourse : tpCourseList) {
//                for (TPRequirement tpRequirement : tpRequirementList) {
//                    tpMatrixService.updateMatrixForNodeCount(tpCourse, tpRequirement);
//                }
//            }
//        }

        this.saveBatch(courseList);
        return true;
    }

    @Override
    public int getMaxSortNum(Long cultureProgramId) {
        QueryWrapper<ObeCultureProgramCourse> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(ObeCultureProgramCourse::getCultureProgramId, cultureProgramId)
                .orderByDesc(ObeCultureProgramCourse::getSortNum)
                .last("limit 1");
        ObeCultureProgramCourse obeCultureProgramCourse = this.getOne(queryWrapper);
        if (obeCultureProgramCourse == null) {
            return 0;
        } else {
            return obeCultureProgramCourse.getSortNum();
        }
    }

    @Override
    public boolean saveSort(List<ObeCultureProgramCourse> courseList) {
        courseList.forEach(t -> {
            if (t.getId() != null && t.getSortNum() != null) {
                UpdateWrapper<ObeCultureProgramCourse> updateWrapper = new UpdateWrapper();
                updateWrapper.lambda().set(ObeCultureProgramCourse::getSortNum, t.getSortNum())
                        .eq(ObeCultureProgramCourse::getId, t.getId());
                this.update(updateWrapper);
            }
        });
        return true;
    }

    @Override
    public boolean removeCourse(Long id) {
//        tpMatrixService.removeMatrixByCondition(null, id, null);
        return this.removeById(id);
    }
}
