package com.qmth.distributed.print.business.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.distributed.print.business.entity.ObeCultureProgramRequirement;
import com.qmth.distributed.print.business.mapper.ObeCultureProgramRequirementMapper;
import com.qmth.distributed.print.business.service.ObeCultureProgramRequirementService;
import com.qmth.teachcloud.common.entity.SysUser;
import com.qmth.teachcloud.common.util.ServletUtil;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 培养方案毕业要求 服务实现类
 * </p>
 *
 * @author xf
 * @since 2024-06-05
 */
@Service
public class ObeCultureProgramRequirementServiceImpl extends ServiceImpl<ObeCultureProgramRequirementMapper, ObeCultureProgramRequirement> implements ObeCultureProgramRequirementService {

    @Override
    public List<ObeCultureProgramRequirement> listRequirement(Long cultureProgramId) {
        QueryWrapper<ObeCultureProgramRequirement> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(ObeCultureProgramRequirement::getCultureProgramId, cultureProgramId)
                .orderByAsc(ObeCultureProgramRequirement::getSortNum);
        return this.list(queryWrapper);
    }

    @Override
    public boolean saveRequirement(ObeCultureProgramRequirement obeCultureProgramRequirement) {
        SysUser sysUser = (SysUser) ServletUtil.getRequestUser();
        // 修改
        if (obeCultureProgramRequirement.getId() != null) {
            obeCultureProgramRequirement.updateInfo(sysUser.getId());
        }
        // 新增
        else {
            obeCultureProgramRequirement.setSortNum(this.getMaxSortNum(obeCultureProgramRequirement.getCultureProgramId(), obeCultureProgramRequirement.getParentId()) + 1);
            obeCultureProgramRequirement.insertInfo(sysUser.getId());
        }
        this.saveOrUpdate(obeCultureProgramRequirement);
        // 节点数变动后，修改矩阵数据
//        List<TPCourse> tpCourseList = tpCourseService.listCourse(tpRequirement.getProfessionalId());
//        if (CollectionUtils.isNotEmpty(tpCourseList)) {
//            for (TPCourse tpCourse : tpCourseList) {
//                tpMatrixService.updateMatrixForNodeCount(tpCourse, tpRequirement);
//            }
//        }
        return true;
    }

    @Override
    public int getMaxSortNum(Long cultureProgramId, Long parentId) {
        QueryWrapper<ObeCultureProgramRequirement> queryWrapper = new QueryWrapper<>();
        LambdaQueryWrapper<ObeCultureProgramRequirement> lambda = queryWrapper.lambda();
        lambda.eq(ObeCultureProgramRequirement::getCultureProgramId, cultureProgramId);
        if (parentId != null) {
            lambda.eq(ObeCultureProgramRequirement::getParentId, parentId);
        }
        lambda.orderByDesc(ObeCultureProgramRequirement::getSortNum);
        lambda.last("limit 1");
        ObeCultureProgramRequirement requirement = this.getOne(queryWrapper);
        if (requirement == null) {
            return 0;
        } else {
            return requirement.getSortNum();
        }
    }

    @Transactional
    @Override
    public boolean removeRequirement(Long id) {
//        tpMatrixService.removeMatrixByCondition(null, null, id);
        return this.removeById(id);
    }
}
