package com.qmth.distributed.print.business.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.distributed.print.business.bean.dto.obe.MatrixTargetDto;
import com.qmth.distributed.print.business.bean.dto.obe.RequirementTargetMatrixDto;
import com.qmth.distributed.print.business.entity.ObeRequirementTargetMatrix;
import com.qmth.distributed.print.business.mapper.ObeRequirementTargetMatrixMapper;
import com.qmth.distributed.print.business.service.ObeRequirementTargetMatrixService;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.LinkedMultiValueMap;

import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;

/**
 * <p>
 * 培养目标与毕业要求关系矩阵 服务实现类
 * </p>
 *
 * @author xf
 * @since 2024-06-05
 */
@Service
public class ObeRequirementTargetMatrixServiceImpl extends ServiceImpl<ObeRequirementTargetMatrixMapper, ObeRequirementTargetMatrix> implements ObeRequirementTargetMatrixService {

    @Override
    public List<RequirementTargetMatrixDto> getMatrix(Long cultureProgramId) {
        List<ObeRequirementTargetMatrix> matrixList = this.baseMapper.listMatrix(cultureProgramId);
        List<RequirementTargetMatrixDto> matrixDtoList = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(matrixList)) {
            LinkedMultiValueMap<String, ObeRequirementTargetMatrix> requirementMap = new LinkedMultiValueMap<>();
            for (ObeRequirementTargetMatrix matrix : matrixList) {
                requirementMap.add(matrix.getRequirementName(), matrix);
            }
            requirementMap.entrySet().stream().forEach(entry -> {
                RequirementTargetMatrixDto requirementTargetMatrixDto = new RequirementTargetMatrixDto();
                requirementTargetMatrixDto.setRequirementName(entry.getKey());

                List<MatrixTargetDto> matrixTargetDtoList = entry.getValue().stream().map(m -> {
                    MatrixTargetDto matrixRequirementDto = new MatrixTargetDto();
                    matrixRequirementDto.setId(m.getId());
                    matrixRequirementDto.setName(m.getTargetName());
                    matrixRequirementDto.setEnable(m.getEnable());
                    return matrixRequirementDto;
                }).sorted(Comparator.comparingLong(o -> o.getCreateTime())).collect(Collectors.toList());
                requirementTargetMatrixDto.setRequirements(matrixTargetDtoList);
                matrixDtoList.add(requirementTargetMatrixDto);
            });
        }
        return matrixDtoList;
    }

    @Transactional
    @Override
    public boolean saveMatrix(List<ObeRequirementTargetMatrix> obeRequirementTargetMatrixList) {
        for (ObeRequirementTargetMatrix tpMatrix : obeRequirementTargetMatrixList) {
            UpdateWrapper<ObeRequirementTargetMatrix> updateWrapper = new UpdateWrapper<>();
            updateWrapper.lambda().set(ObeRequirementTargetMatrix::getEnable, tpMatrix.getEnable())
                    .eq(ObeRequirementTargetMatrix::getId, tpMatrix.getId());
            this.update(updateWrapper);
        }
        return true;
    }
}
